-- Version 0.4

--[[--------------------------------------------------------------------------

This plugin draws oversized Time Signatures in the staff.

To start the plugin just insert a 'StaffSig' instance of the object at the beginning of the staff and it will automatically oversize any Time Signature colored in one of the 7 non-default colors.
The color which activates the plugin must be set manually.

OPTIONS:
- Time Signature Color: Here you have to indicate which color will be used for plugin activation.
- Scale (%): This option sets the oversizing percent. This setting can be modified with +/- keys.

CONSIDERATIONS:
- The Highlight color used might be set to white.
- The object's class must be 'Span'.

--]]--------------------------------------------------------------------------


local userObjTypeName = ...

local Idx = nwc.drawpos.new()
local NextTimeSig = nwc.drawpos.new()


local object_spec = {
{ id='Col', label='Time Signature Color', type='enum', default='Highlight 7', list={'Highlight 1', 'Highlight 2', 'Highlight 3', 'Highlight 4', 'Highlight 5', 'Highlight 6', 'Highlight 7'}},
{ id='Scale', label='Scale (%)', type='float', default=100, min=100, max=175, step=5 },
}


local function do_create(t)
	t.Class = 'Span'
end


local function do_span(t)
	return 2048,'bars'
end


local function do_spin(t,d)
	t.Scale = t.Scale + d*5
	t.Scale = t.Scale
end


local function do_draw(t)
 if t.Class == 'Span' then

  local w = nwc.toolbox.drawStaffSigLabel(UserObjTypeName)
  if not nwcdraw.isDrawing() then return w end

  if Idx:find('next', 'user', userObjTypeName) then return end

  nwcdraw.setFontClass('StaffSymbols')
  nwcdraw.setFontSize(nwcdraw.getFontSize()*t.Scale*.01)

	while Idx:find('next', 'TimeSig') do
	    NextTimeSig:find('next', 'TimeSig')
	    local NextTimeSig_Prop = NextTimeSig:objProp('Signature')
	    local NextTimeSig_Pos = NextTimeSig:staffPos()
	    local xNext,yNext = NextTimeSig:xyAnchor()
	    local Color_Used = NextTimeSig:objProp('Color')
	    local Next_Col = 'Highlight ' .. Color_Used

	    local Scale = t.Scale*.01
	    local Beats
	    local Value
	    local Space

	    if NextTimeSig_Prop == 'Common' then
	      Beats = 4
	      Value = 4
	      Space = 0.5
	    elseif NextTimeSig_Prop == 'AllaBreve' then
	      Beats = 2
	      Value = 2
	      Space = 0.5
	    elseif string.len(NextTimeSig_Prop) == 3 and string.sub(NextTimeSig_Prop,2,2) == '/' then
	      Beats = string.sub(NextTimeSig_Prop,1,1)
	      Value = string.sub(NextTimeSig_Prop,3)
	      Space = 0.5
	    elseif string.len(NextTimeSig_Prop) == 4 and string.sub(NextTimeSig_Prop,2,2) == '/' then
	      Beats = string.sub(NextTimeSig_Prop,1,1)
	      Value = string.sub(NextTimeSig_Prop,3)
	      Space = 1
	    elseif string.len(NextTimeSig_Prop) >= 4 and string.sub(NextTimeSig_Prop,3,3) == '/' then
	      Beats = string.sub(NextTimeSig_Prop,1,2)
	      Value = string.sub(NextTimeSig_Prop,4)
	      Space = 1
	    elseif string.len(NextTimeSig_Prop) > 4 and string.sub(NextTimeSig_Prop,4,4) == '/' then
	      Beats = string.sub(NextTimeSig_Prop,1,3)
	      Value = string.sub(NextTimeSig_Prop,5)
	      Space = 1.5
	    end

	    if Next_Col == t.Col then
	      nwcdraw.moveTo(xNext+Space*Scale,yNext+4*Scale)
		nwcdraw.alignText('middle','center')
	      nwcdraw.text(Beats)
	      nwcdraw.moveTo(xNext+Space*Scale,yNext-0.1*Scale)
		nwcdraw.alignText('middle','center')
	      nwcdraw.text(Value)

	      nwcdraw.line(xNext-0.5,yNext+4,xNext+2+Space*2,yNext+4)
	      nwcdraw.line(xNext-0.5,yNext+2,xNext+2+Space*2,yNext+2)
	      nwcdraw.line(xNext-0.5,yNext,xNext+2+Space*2,yNext)
	      nwcdraw.line(xNext-0.5,yNext-2,xNext+2+Space*2,yNext-2)
	      nwcdraw.line(xNext-0.5,yNext-4,xNext+2+Space*2,yNext-4)

	    end
	end 
 else

  local w = nwc.toolbox.drawStaffSigLabel('ERROR: Not Span Class')
  if not nwcdraw.isDrawing() then return w end

 end
end


return {
	spec = object_spec,
	create = do_create,
	span = do_span,
	spin = do_spin,
	width = do_draw,
	draw = do_draw,
}